# J.COp DL
J.COp DL is a deep Learning package to complement pytorch workflow. It includes pytroch callbacks and metrics.

The project started in August 2019 as a tool to teach deep learning for beginner. Together with LuWiji and J.COp ML, J.COP DL is developed by Wira D. K. Putra as complementary for his machine learning curriculum for young machine learning enthusiast.

# User Installation Guide
```
pip install jcopdl
```